﻿/* AutoDetect.cs
 * part of zaaReloaded2
 * 
 * Copyright 2015 Daniel Kraus
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace zaaReloaded2
{
    class AutoDetect
    {

        /// <summary>
        /// Attempts to automatically detect laboratory data in the Word
        /// document.
        /// </summary>
        public void AutoDetect()
        {
            if (Document == null)
            {
                throw new InvalidOperationException(
                    "Automatic laboratory detection requires a document.");
            }

            // If the 'Labor' bookmark exists, go to it.
            if (Document.Bookmarks.Exists("Labor"))
            {
                Document.Bookmarks["Labor"].Range.Collapse(WdCollapseDirection.wdCollapseStart);
            }

            // If the current paragraph looks like a Lauris paragraph, fine.
            // If it does not look like a Lauris paragraph, move the cursor
            // up until we find one.
            string s = Document.ActiveWindow.Selection.Paragraphs[1].Range.Text;

            // If we found a Lauris paragraph by moving up, start extending the
            // selection upwards until we encounter a paragraph that is not a
            // Lauris paragraph.

            // If we have previously reached the start of the document without finding
            // a Lauris paragraph, go back to where we started and move the
            // cursor down paragraph by paragraph until we find a Lauris
            // paragraph.

            // If we found a Lauris paragraph by moving down, start extending the
            // selection downwards until we encounter a paragraph that is not a
            // Lauris paragraph.
        }
    }
}
